@@ -3,9 +3,9 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
-use JSON::XS;
+use JSON::XS qw//;
 use MIME::Base64;
 
 sub new {
